summaryrefslogtreecommitdiffstats
path: root/src/NetherPortalScanner.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/NetherPortalScanner.h')
-rw-r--r--src/NetherPortalScanner.h9
1 files changed, 6 insertions, 3 deletions
diff --git a/src/NetherPortalScanner.h b/src/NetherPortalScanner.h
index e9e210b2f..d6ed6326d 100644
--- a/src/NetherPortalScanner.h
+++ b/src/NetherPortalScanner.h
@@ -16,7 +16,7 @@ class cWorld;
class cNetherPortalScanner : public cChunkStay
{
public:
- cNetherPortalScanner(cEntity * a_MovingEntity, cWorld * a_DestinationWorld, Vector3d a_DestPosition, int a_MaxY);
+ cNetherPortalScanner(UInt32 a_MovingEntityID, eDimension a_PreviousDimension, cWorld * a_DestinationWorld, Vector3d a_DestPosition, int a_MaxY);
virtual void OnChunkAvailable(int a_ChunkX, int a_ChunkY) override;
virtual bool OnAllChunksAvailable(void) override;
virtual void OnDisabled(void) override;
@@ -49,8 +49,11 @@ private:
/** Whether the given location is a valid location to build a portal. */
bool IsValidBuildLocation(Vector3i a_BlockPosition);
- /** The entity that's being moved. */
- cEntity * m_Entity;
+ /** The ID of the entity that's being moved. */
+ UInt32 m_EntityID;
+
+ /** The dimension the entity was originally in. */
+ eDimension m_PreviousDimension;
/** The world we're moving the entity to. */
cWorld * m_World;